%global name souffle
# This is the name of the github repo
%global github souffle-lang/souffle
# This is the git tag in the github repo
%global version 2.4
# This is the version in X.Y.Z format
%global short_version 2.4

Name: %{name}
Summary: Soufflé language tools
Version: %{version}
Release: 1
License: The Universal Permissive License (UPL), Version 1.0
URL: https://github.com/%{github}
# E.g. https://github.com/souffle-lang/souffle/archive/2.3.tar.gz
Source0: %{url}/archive/%{version}.tar.gz

BuildRequires: gcc-c++ pkg-config
BuildRequires: bison clang cmake doxygen flex make mcpp
BuildRequires: libffi-devel ncurses-devel sqlite-devel zlib-devel
BuildRequires: bash-completion

%if %{defined fedora}
BuildRequires: python redhat-lsb-core
%endif

%if %{defined centos} || %{defined rhel}
BuildRequires: python39
BuildRequires: redhat-lsb-core
%endif

Requires: libffi ncurses sqlite zlib

%description
Soufflé is a logic programming language inspired by Datalog.

%prep
%autosetup -n %{name}-%{short_version} -p 1

%if %{defined fedora}
%build
export CXXFLAGS="%{?build_cxxflags} -Wno-parentheses -Wno-unused-variable -Wno-deprecated-declarations"
%cmake -DSOUFFLE_DOMAIN_64BIT=ON -DSOUFFLE_GIT=OFF -DSOUFFLE_BASH_COMPLETION=ON -DSOUFFLE_VERSION=%{short_version}
%cmake_build

%install
%cmake_install

%check
%ctest --output-on-failure --progress --stop-on-failure
%endif

%if %{defined centos} || %{defined rhel}
%build
mkdir builddir
%cmake -DSOUFFLE_DOMAIN_64BIT=ON -DSOUFFLE_GIT=OFF -DSOUFFLE_BASH_COMPLETION=ON -DSOUFFLE_VERSION=%{short_version} -B builddir
%make_build -C builddir

%install
%make_install -C builddir

%check
cd builddir
%ctest --output-on-failure --progress --stop-on-failure
%endif

%files
%license LICENSE
%{_bindir}/souffle
%{_bindir}/souffle-compile.py
%{_bindir}/souffleprof
%{_includedir}/souffle/*
/usr/share/bash-completion/completions/souffle

%changelog
* Sat Jun 3 2023 Christoph Muellner <cmuellner@gcc.gnu.org 2.4
- Update to Souffle 2.4

* Tue Sep 20 2022 Christoph Muellner <cmuellner@gcc.gnu.org> 2.3
- Update to Souffle 2.3

* Sun Mar 13 2022 Christoph Muellner <cmuellner@gcc.gnu.org> 2.2
- Update to Souffle 2.2

* Thu Nov 11 2021 Christoph Muellner <cmuellner@gcc.gnu.org> 2.1-2
- Include packported patch to fix _GLIBCXX_ASSERTIONS issue (upstream #2038)

* Tue Sep 21 2021 Christoph Muellner <cmuellner@gcc.gnu.org> 2.1-1
- Initial package for Souffle
